@@ -1,10 +1,10 @@
 from enum import Enum
 
 REF = "ref"
-COMMIT = "commit"
+# COMMIT = "commit"
 TAG = "tag"
-BRANCH = "branch"
-FILE = "file"
+# BRANCH = "branch"
+# FILE = "file"
 
 ACTION = "action"
 TYPE = "type"
@@ -18,9 +18,3 @@ NUMBER = "number"
 class Action(Enum):
     REGISTER = "register"
     PROMOTE = "promote"
-
-
-class VersionPart(Enum):
-    MAJOR = "major"
-    MINOR = "minor"
-    PATCH = "patch"
