@@ -50,9 +50,10 @@ def name_tag(
             raise MissingArg(arg="repo")
         numbers = []
         for tag in repo.tags:
-            parsed = parse_name(tag.name)
+            parsed = parse_name(tag.name, raise_on_fail=False)
             if (
-                (parsed[NAME] == name)
+                parsed
+                and (parsed[NAME] == name)
                 and (parsed[ACTION] == Action.PROMOTE)
                 and (NUMBER in parsed)
             ):
@@ -202,6 +203,7 @@ def version_from_tag(tag: git.Tag) -> BaseVersion:
         name=mtag.version,
         created_at=mtag.created_at,
         author=tag.tag.tagger.name,
+        author_email=tag.tag.tagger.email,
         commit_hexsha=tag.commit.hexsha,
         tag=tag.name,
     )
@@ -226,6 +228,7 @@ def promotion_from_tag(
                     name=tag.commit.hexsha,
                     created_at=mtag.created_at,
                     author=tag.tag.tagger.name,
+                    author_email=tag.tag.tagger.email,
                     commit_hexsha=tag.commit.hexsha,
                 )
             )
@@ -236,6 +239,7 @@ def promotion_from_tag(
         stage=mtag.stage,
         created_at=mtag.created_at,
         author=tag.tag.tagger.name,
+        author_email=tag.tag.tagger.email,
         commit_hexsha=tag.commit.hexsha,
         tag=tag.name,
     )
