@@ -84,14 +84,17 @@ def test_register(repo_with_artifact):
     assert latest.name == vname2
 
 
-def test_promote(repo_with_artifact):
+def test_promote(repo_with_artifact: Tuple[git.Repo, str]):
     repo, name = repo_with_artifact
     stage = "staging"
+    repo.create_tag("v1.0.0")
+    repo.create_tag("wrong-tag-unrelated")
     gto.api.promote(
         repo.working_dir, name, stage, promote_ref="HEAD", name_version="v0.0.1"
     )
     promotion = gto.api.find_promotion(repo.working_dir, name, stage)
     author = repo.commit().author.name
+    author_email = repo.commit().author.email
     _check_obj(
         promotion,
         dict(
@@ -99,6 +102,7 @@ def test_promote(repo_with_artifact):
             version="v0.0.1",
             stage=stage,
             author=author,
+            author_email=author_email,
             commit_hexsha=repo.commit().hexsha,
         ),
         {"created_at", "promotions", "tag"},
